<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>Перейти к PDF</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translatorcomment>Контекст работы со словарём</translatorcomment>
        <translation>Нет вариантов</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translatorcomment>Контекст работы со словарём</translatorcomment>
        <translation>Пропустить слово</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>Невозможно удалить</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>Некоторые вспомогательные файлы невозможно удалить. Возможно у вас нет прав на удаление.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translatorcomment>Заголовок вспомогательного окна</translatorcomment>
        <translation>Подтвердите удаление</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>Удаляемые вспомогательные файлы:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить всё</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>Переключить</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translatorcomment>Заголовок поискового окна</translatorcomment>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Find:</source>
        <translatorcomment>Строка-подсказка действия</translatorcomment>
        <translation>Найти:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>По &amp;кругу</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Искать на&amp;зад</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>Искать среди в&amp;ыделенного</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Найти &amp;все</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>Искать во всех о&amp;ткрытых файлах</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>С &amp;учётом регистра</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>Выражения &amp;целиком</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Регулярное выражение</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>История поиска пуста</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translatorcomment>Текст выводится при неправильном вводе регулярного выражения</translatorcomment>
        <translation>(ошибка)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>Разбить на строки</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>Разбить на строки по:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>Размеру текущего окну</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>Длине строки:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>Переразбить абзацы</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>Объединить строки</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>Недавно открытые файлы</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>Ошибка при загрузке файла «%1»; возможно это не PDF документ.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>Нет данных SyncTeX</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX: «%1»</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>страница %1 из %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>К сожалению, в данной версии %1 нет возможности вывода на печать Pdf документов по ряду технических причин.
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>Открыть этот файл в приложении по умолчанию для печати?</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation> (не забудьте закрыть его во избежании проблем с доступом к файлу)</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>безназвания.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Показать</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Вёрстка</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>О программе TeXworks...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Первая страница</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Предыдущая страница</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Следующая страница</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Последняя страница</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>Перейти к странице...</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Сценарии</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>Сценарии в TeXworks</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>По размеру окна</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Натуральный размер</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>По ширине страницы</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Открыть...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Каскадом</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Плиткой</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translatorcomment>Можно жаргон: исходнику</translatorcomment>
        <translation>Перейти к исходному файлу</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Новый из шаблона...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>На весь экран</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>Линза</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Прокрутить</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>Выделить текст</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Выделить изображение</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Перейти на домашнюю страницу TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Отправить сообщение в список рассылки</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translatorcomment>Рядом</translatorcomment>
        <translation>Бок о бок</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Расположить слева</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Расположить справа</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Выйти из TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Продолжить поиск</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Перезагрузить список сценариев</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>Печать Pdf...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Настройки и ресурсы...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Очистить список недавно открытых файлов</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Управление сценариями</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Показать каталог со сценариями</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>О сценариях...</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Найти...</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Вёрстка</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Прервать вёрстку</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>Ошибка при запуске SyncTeX</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation>Перейти к предыдущему виду</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Постранично</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Постранично свитком</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>По две страницы свитком</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>Перейти к исходному файлу</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>Перейти к странице</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>Страница:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Открыть URL-адрес</translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation>Вы собираетесь открыть URL-адрес %1. Открывать неизвестные или непроверенные URL-адреса может быть небезопасно.
Продолжить?</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Настройка...</translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translation>Установить масштаб</translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation>Масштаб:</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>История поиска пуста</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>Поиск в PDF</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>По &amp;кругу</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Искать на&amp;зад</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Найти &amp;все</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>С &amp;учётом регистра</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translatorcomment>Возможные варианты: Связать с исходным файлом, или Сцепить с исходником.</translatorcomment>
        <translation>&amp;Синхронизировать с исходным файлом</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>Выберите каталог</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>Новый инструмент вёрстки</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>Язык системы [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>Настройки TeXworks</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>Маленькие иконки</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>Средние иконки</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>Большие иконки</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>Показывать текст и иконки</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>При запуске начать с</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>Пустого документа</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>Окна выбора шаблона</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>Окна открытия файла</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Редактор</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>Значения по умолчанию</translation>
    </message>
    <message>
        <source> pt</source>
        <translation> пт</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Величина Tab:</translation>
    </message>
    <message>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>Переносить строки</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>Подсветка синтаксиса:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>Режим авто-отступа:</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>Режим авто кавычек:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>Язык для проверки орфографии:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Кодировка:</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;Замечание:&lt;/em&gt; это параметры по умолчанию. Их изменение не скажется на уже открытых окнах. Используйте для этого соответствующие пункты в меню «Формат».</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>Масштаб по умолчанию</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>Натуральный размер</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>По ширине страницы</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>По размеру окна</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>Фиксированное увеличение:</translation>
    </message>
    <message>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>Линза</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Маленькая</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Средняя</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Большая</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>Круглой формы</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>Разрешение на экране:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation type="obsolete"> дпи</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>Вёрстка</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>Пути к TeX и сопутствующим программам</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>Инструменты вёрстки</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Правка...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>По умолчанию:</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translatorcomment>Режим «скрытия панели вывода»</translatorcomment>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translatorcomment>Режим «скрытия панели вывода»</translatorcomment>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translatorcomment>Режим «скрытия панели вывода»</translatorcomment>
        <translation>В случае успеха</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Сценарии</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>Разрешить сценариям читать все файлы (файлы сценариев и документов всегда доступны на чтение)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>Разрешить сценариям записывать файлы</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>Включить подключаемые языки сценариев (может привести к обходу других ограничений на поведение сценариев)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Отладка</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>Включить отладчик QtScript</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>Разрешить сценариям запускать системные программы</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>Номера строк</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>Глобальные параметры редактора</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>Подсветка текущей строки</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>Автодополнения</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>Скрывать панель вывода:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;Никогда:&lt;/strong&gt; никогда не скрывать панель вывода работы программы после вёрстки.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Автоматически:&lt;/strong&gt; скрывать панель вывода работы программы после успешной вёрстки, но только если она была скрыта ранее.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;В случае успеха:&lt;/strong&gt; скрывать панель вывода программы после успешной вёрстки независимо от предыдущего состояния.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>Кнопки на панеле:</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>Открывать для просмотра PDF вместе с TeX файлами</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>Отображение страниц:</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Постранично</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Постранично свитком</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>По две страницы свитком</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>Документы TeX (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>Документы LaTeX (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>Базы данных BibTeX (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>Стилевые файлы (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>Файлы классов (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>Документированные макропакеты (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Текстовые файлы (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>Документы PDF (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>Файлы журналов (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>Вспомогательные файлы (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation variants="yes">
            <lengthvariant>Заменить</lengthvariant>
            <lengthvariant></lengthvariant>
        </translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Заменить всё</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>История поиска пуста</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>История замены пуста</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(ошибка)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>Заменить:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>На:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>По &amp;кругу</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Искать на&amp;зад</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>Заменить в &amp;выделенной части</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>Заменить во всех о&amp;ткрытых файлах</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>С &amp;учётом регистра</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>Слова &amp;целиком</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Регулярное выражение</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>Настройки и ресурсы TeXworks</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>Размещение</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>Настройки:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>Ресурсы:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>Реестр (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation type="unfinished">Передвиньте линейку или измените значение, чтобы задать масштаб.
Общепринятые размеры страниц также указаны на линейке (чтобы их увидеть измените размер окна).
Используйте контекстное меню чтобы изменить единицы измерения.</translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation> дпи</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation>Размер A4</translation>
    </message>
    <message>
        <source>Letter</source>
        <translation>Размер Letter</translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation>см</translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation>дюйм</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Name: </source>
        <translation>Название: </translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>Контекст: </translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Описание: </translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>Автор: </translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>Комбинация: </translation>
    </message>
    <message>
        <source>File: </source>
        <translation>Файл: </translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>Язык: </translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>Перехватчик: </translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Управление сценариями</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>Сценарии перехватчики</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>Автономные сценарии</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>Результаты поиска - %1 (%2 найдено)</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Строка</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Начало</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Конец</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>Результаты поиска</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Новый из шаблона...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Открыть...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Недавно открытые файлы</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>About </source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Перейти на домашнюю страницу TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Отправить сообщение в список рассылки</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 это простая программа для редактирования, вёрстки и просмотра документов TeX.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt;Распространяется по лицензии &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, вторая редакция или (по вашему усмотрению) любой последующей редакции.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; библиотека обработки PDF, разработчики Kristian H&amp;#xF8;gsberg, Albert Astals Cid и другие.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Идея и ресурсы взяты из &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt;, автор Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;Технология &lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; от J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;Некоторые иконки взяты из проекта &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;%1 перевод выполнил %2.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Владимир/irk.translator@gmail.com</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>О программе %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>Ошибка при подключении к «%1»; возможно ваш браузер или почтовый клиент не настроен?</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>Ошибка про создании окна</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>Произошло что-то непредвиденное; %1 не смог создать новое окно. Приложение будет закрыто.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>Отсутствует заданный по умолчанию каталог с программами</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>Невозможно найти какой-либо из предопределённых каталогов с TeX и сопутствующих программ.&lt;p&gt;&lt;small&gt;Чтобы сверстать документ нужно установить путь к каталогу (каталогам) с программами вашего дистрибутива TeX, используя вкладку Вёрстка в окне Настройки.&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>Невозможно найти файл справки.</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>Запрос прав доступа</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>Сценарий «%1» пытается открыть файл «%2» без достаточных на то прав доступа. Открыть файл?</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Очистить список недавно открытых файлов</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;Версия %1 (%2) [рев.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;Версия %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Выйти из TeXworks</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Платформа приложений Qt&lt;/a&gt; v%1 компании Qt.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; проверка орфографии, разработчик L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>Внутренняя ошибка</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>Не удалось выполнить системную команду: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>Ошибка при выполнении системной команды: %1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>Запуск системных команд отключён (см. Настройки)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>Невозможно открыть «%1».</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>Доступ на чтение всех файлов отключён (см. Настройка)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>Невозможно открыть файл «%1» для чтения</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script result</source>
        <translation>Результат работы сценария</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>неизвестная ошибка</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>Сценарии можно использовать чтобы добавить новые команды к %1, расширяя или изменяя его действия.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>Подробнее о создании и использовании сценариев см. %1&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>Языки сценариев доступные в данной копии %1:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>О сценариях</translation>
    </message>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>Сценарий «%1»: %2</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>Ошибка в сценарии</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(отключено в Настройках)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>ОШИБКА: сбой в коде %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>ОШИБКА: код завершения %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>Теги</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>Структура</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>Нет тегов</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>Новый документ</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Недавно открытые файлы</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>Документ «%1» был изменён.
Хотите сохранить ваши изменения?</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translatorcomment>комбинация клавиш: не сохранять</translatorcomment>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>Сбросить все изменения в документе «%1» и вернуться к последней сохранённой редакции?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Отменить последние изменения</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>Неопознанная кодировка</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>Кодировка текста %1, используемая в %2 не поддерживается.

Она будет интерпретирована как %3, что может привести к искажению теста.</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>Файл на диске был изменён</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 был изменён другой программой.

Отбросить текущие изменения и загрузить файл с диска?</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 был изменён другой программой.

Продолжить сохранение этого файла, перезаписав его редакцию на диске?</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>Документ «%1» не был сохранён</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>Текст невозможно перекодировать</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>Этот документ содержит символы, которые нельзя использовать в кодировке %1.

Если вы продолжите они будут заменены на коды по умолчанию. Или же вы можете использовать другую кодировку (например UTF-8), чтобы избежать потерю данных.</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>Невозможно прочитать файл «%1»:
%2</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>Невозможно записать файл «%1»:
%2</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>Прервать вёрстку?</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>Процесс вёрстки всё ещё идёт, он должен быть остановлен до закрытия окна.
Остановить его?</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translatorcomment>комбинация клавиш: отменить изменения</translatorcomment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>Файл «%1» загружен</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 постоянно изменяется другой программой.

После завершения работы внешней программы вручную выполните «Файл &gt; Вернуться к сохранённому».</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>Ошибка при записи файла</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>Возможно произошла ошибка при сохранении файла. Сохраните копию в другом месте.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>Файл «%1» сохранён</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>безназвания-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>Строка %1 из %2; столбец %3</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>Открыть заново использую выбранную кодировку</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>Открыть текущий документ заново в выбранной кодировке.

Выбранная кодировка перекроет кодировку по умолчанию и все строки «%! TEX encoding».</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>Несохранённые изменения</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>Файл который вы пытаетесь открываете заново содержит несохранённые изменения.

Отбросить текущие изменения и открыть файл заново с диска в кодировке %1?</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>Перейти к строке</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Номер строки:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>Неправильное регулярное выражение</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Не найдено</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>Найден %n вариант</numerusform>
            <numerusform>Найдено %n варианта</numerusform>
            <numerusform>Найдено %n вариантов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n вариант</numerusform>
            <numerusform>%n варианта</numerusform>
            <numerusform>%n вариантов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n документ</numerusform>
            <numerusform>%n документа</numerusform>
            <numerusform>%n документов</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>Заменено %1 в %2</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>Заменён %n вариант</numerusform>
            <numerusform>Заменено %n варианта</numerusform>
            <numerusform>Заменено %n вариантов</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>Нельзя верстать несохранённый документ</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>Главный документ %1 недоступен для чтения</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 не настроен должным образом</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>Невозможно выполнить %1</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Чтобы сверстать документ вам необходим &lt;b&gt;дистрибутив TeX&lt;/b&gt;, установленный в вашей системе, например &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; или &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Чтобы сверстать документ вам необходим &lt;b&gt;дистрибутив TeX&lt;/b&gt;, установленный в вашей системе, например &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>Чтобы сверстать документ вам необходим &lt;b&gt;дистрибутив TeX&lt;/b&gt;, установленный в вашей системе, например &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;. В большинстве систем такой дистрибутив TeX доступен в виде пакета.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>После установки дистрибутива TeX необходимо настроить TeXworks в Правка -&gt; Настройки -&gt; Вёрстка.</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>Проверьте настройки инструмента %1 и пути в окне Настройки.</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Прервать вёрстку</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>Установить движок вёрстки на «%1»</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>Движок вёрстки «%1» не определён</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Файлы не найдены</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>В данный момент у документа нет связанных с ним вспомогательных файлов.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>безназвания.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Проверка орфографии</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>Изменить регистр</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Вёрстка</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>Вывод работы программы</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Показать</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>Режим авто-отступа</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>Подсветка синтаксиса</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>Автоматические кавычки</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Сценарии</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>Сценарии в TeXworks</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>Панель вёрстки</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>Панель редактирования</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Открыть...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Сохранить как...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>Вернуться к сохранённому</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Найти...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Продолжить поиск</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>Заменить...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>Скопировать в Найти</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>Скопировать в Заменить</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>Перейти к строке...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>Найти выделенное</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить всё</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Шрифт...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Вставить отступ</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Убрать отступ</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Закомментировать</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation>Ctrl+Shift+]</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>Раскомментировать</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation>Ctrl+Shift+[</translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>Переносить строки</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>О программе TeXworks...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Каскадом</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Плиткой</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>Перейти к просмотру</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation>Ctrl+\</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Новый из шаблона...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>Показать выделенное</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>ВЕРХНИЙ РЕГИСТР</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>нижний регистр</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>Баланс разделителей</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Перейти на домашнюю страницу TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Отправить сообщение в список рассылки</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Бок о бок</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Расположить слева</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Расположить справа</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>Продолжить замену</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>Удалить вспомогательные фалы...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Выйти из TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>Сменить регистр</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Показать каталог со сценариями</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Перезагрузить список сценариев</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Сохранить всё</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation>Ctrl+Alt+S</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Настройки и ресурсы...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Очистить список недавно открытых файлов</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Управление сценариями</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>Автоматически менять фокус</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>О сценариях...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>Применить к выделению</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>Программа «%1» не найдена.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>Поиск проводили в каталогах:</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>Вёрстка прервана пользователем</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Вёрстка</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>Разбивать на строки...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>Номера строк</translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>Скрыть панель вывода</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>Проблема отрисовки</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>Произошла ошибка при отрисовке загруженного в редактор документа. Она вызвана ошибкой в Qt и может привести к аварийному завершению TeXworks в некоторых случаях. Внешние признаки этой проблемы — это исчезающие или перекрывающиеся строки. Для обхода проблемы попрообуйте:
 -) выключить и включить подсветку синтаксиса;
 -) выключитюь и включить нумерацию строк;
 -) изменить размер окна.

Приносим извинения за неудобства.</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>Показать панель вывода</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>Записать метку порядка байтов UTF-8</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>Новый документ из шаблона</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>Выберите шаблон для нового документа:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>Select program file</source>
        <translation>Выберите программу</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>Непригодная программа</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>Файл «%1» не является программой!</translation>
    </message>
    <message>
        <source>NewArgument</source>
        <translation>НовыйПараметр</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>Настройка инструмента вёрстки</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Программа:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Параметры:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>Показать PDF после обработки</translation>
    </message>
</context>
</TS>
